@@ -18,7 +18,7 @@ use Socket;
 # IO::Socket and Socket already import stuff here - possibly AF_INET6
 # and PF_INET6 so selectively import things from Socket6.
 use Socket6 (
-    qw(AI_PASSIVE inet_ntop inet_pton getaddrinfo 
+    qw(AI_PASSIVE getaddrinfo
     sockaddr_in6 unpack_sockaddr_in6_all pack_sockaddr_in6_all in6addr_any)
 );
 
@@ -27,7 +27,7 @@ use Exporter;
 use Errno;
 
 @ISA = qw(IO::Socket);
-$VERSION = "2.59";
+$VERSION = "2.60";
 #Purpose: allow protocol independent protocol and original interface.
 
 my $EINVAL = exists(&Errno::EINVAL) ? Errno::EINVAL() : 1;
@@ -55,7 +55,7 @@ sub _sock_info {
   my @serv = ();
 
   if (defined $addr) {
-	if (!inet_pton(AF_INET6,$addr)) {
+	if (!Socket6::inet_pton(AF_INET6,$addr)) {
          if($addr =~ s,^\[([\da-fA-F:]+)\]:([\w\(\)/]+)$,$1,) {
    	     $port = $2;
          } elsif($addr =~ s,^\[(::[\da-fA-F.:]+)\]:([\w\(\)/]+)$,$1,) {
@@ -229,11 +229,14 @@ sub configure {
                 return _error($sock, $!, "sockopt: $!");
         }
 
-        if( ( $family == AF_INET )
-            ? ((sockaddr_in($lres))[1] ne INADDR_ANY)
-            : ((sockaddr_in6($lres))[1] ne in6addr_any) ) {
-            $sock->bind($lres) or
-                return _error($sock, $!, "bind: $!");
+        if ( $family == AF_INET ) {
+            my ($p,$a) = sockaddr_in($lres);
+            $sock->bind($lres) or return _error($sock, $!, "bind: $!")
+                if ($a ne INADDR_ANY  or $p!=0);
+        } else {
+            my ($p,$a) = sockaddr_in6($lres);
+            $sock->bind($lres) or return _error($sock, $!, "bind: $!")
+                if ($a ne in6addr_any  or $p!=0);
         }
 
         if(exists $arg->{Listen}) {
@@ -331,7 +334,7 @@ sub sockhost {
     @_ == 1 or croak 'usage: $sock->sockhost()';
     my ($sock) = @_;
     return undef unless (my $addr = $sock->sockaddr);
-    inet_ntop($sock->sockdomain, $addr);
+    Socket6::inet_ntop($sock->sockdomain, $addr);
 }
 
 sub sockflow
@@ -368,7 +371,7 @@ sub peerhost {
     @_ == 1 or croak 'usage: $sock->peerhost()';
     my ($sock) = @_;
     return undef unless (my $addr = $sock->peeraddr);
-    inet_ntop($sock->sockdomain, $addr);
+    Socket6::inet_ntop($sock->sockdomain, $addr);
 }
 
 sub peerflow
@@ -509,7 +512,7 @@ Suppose either you have no IPv6 connectivity or www.perl.org has no http service
    $sock = IO::Socket::INET6->new('[::1]:25');
 
    $sock = IO::Socket::INET6->new(PeerPort  => 9999,
-                                 PeerAddr  => inet_ntop(AF_INET6,in6addr_broadcast),
+                                 PeerAddr  => Socket6::inet_ntop(AF_INET6,in6addr_broadcast),
                                  Proto     => udp,    
                                  LocalAddr => 'localhost',
                                  Broadcast => 1 ) 
